@@ -11,6 +11,13 @@
 #' df <- data.frame(x = runif(100), y = sample(c("A", "B"), 100, TRUE))
 #' effect_size_t(df, "x", "y")
 effect_size_t <- function(data, response, group, na.rm = TRUE){
+
+  # # Handle NSE
+  # if (!is.character(substitute(response)) & !is.character(substitute(group))) {
+  #   response <- deparse(substitute(response))
+  #   group    <- deparse(substitute(group))
+  # }
+
   # Check the type of the group
   if (is.factor(data[[group]])) {
     groups <- levels(data[[group]])
@@ -36,7 +43,7 @@ effect_size_t <- function(data, response, group, na.rm = TRUE){
   var2 <- var(y)
 
   # Calculate pooled variance and difference of means
-  s    <- sqrt(sum(n1 * var1, n2 * var2)/((n1 + n2) - 2))
+  s    <- sqrt(sum((n1 - 1) * var1, (n2 - 1) * var2)/((n1 + n2) - 2))
   m_d  <- mean(x) - mean(y)
 
   # Get effect size (absolute)
